@@ -310,6 +310,20 @@ var addOperatorScenarios = []expressionScenario{
 			"D0, P[], (!!map)::a: !cat Saturday, 15-Dec-01 at 6:00AM GMT\n",
 		},
 	},
+	{
+		skipDoc:     true,
+		description: "empty add shouldn't add",
+		document:    `[]`,
+		expression:  `.[]  | (.a + "cat")`,
+		expected:    []string{},
+	},
+	{
+		skipDoc:     true,
+		description: "empty add shouldn't add",
+		document:    `[]`,
+		expression:  `.[]  | (.a + "cat" + .b)`,
+		expected:    []string{},
+	},
 	{
 		skipDoc:        true,
 		description:    "Add to empty",
