@@ -142,15 +142,18 @@ func withEntriesOperator(d *dataTreeNavigator, context Context, expressionNode *
 			return Context{}, err
 		}
 
-		result, err := d.GetMatchingNodes(splatted, expressionNode.RHS)
-		log.Debug("expressionNode.Rhs %v", expressionNode.RHS.Operation.OperationType)
-		log.Debug("result %v", result)
-		if err != nil {
-			return Context{}, err
+		newResults := list.New()
+
+		for itemEl := splatted.MatchingNodes.Front(); itemEl != nil; itemEl = itemEl.Next() {
+			result, err := d.GetMatchingNodes(splatted.SingleChildContext(itemEl.Value.(*CandidateNode)), expressionNode.RHS)
+			if err != nil {
+				return Context{}, err
+			}
+			newResults.PushBackList(result.MatchingNodes)
 		}
 
 		selfExpression := &ExpressionNode{Operation: &Operation{OperationType: selfReferenceOpType}}
-		collected, err := collectTogether(d, result, selfExpression)
+		collected, err := collectTogether(d, splatted.ChildContext(newResults), selfExpression)
 		if err != nil {
 			return Context{}, err
 		}
@@ -162,7 +165,7 @@ func withEntriesOperator(d *dataTreeNavigator, context Context, expressionNode *
 		collected.HeadComment = candidate.HeadComment
 		collected.FootComment = candidate.FootComment
 
-		log.Debugf("**** collected %v", collected.LeadingContent)
+		log.Debugf("collected %v", collected.LeadingContent)
 
 		fromEntries, err := fromEntriesOperator(d, context.SingleChildContext(collected), expressionNode)
 		if err != nil {
