@@ -15,6 +15,13 @@ var mapOperatorScenarios = []expressionScenario{
 			"D0, P[], (!!seq)::[6, 7, 8]\n",
 		},
 	},
+	{
+		skipDoc:    true,
+		expression: `[] | map(. + 42)`,
+		expected: []string{
+			"D0, P[], (!!seq)::[]\n",
+		},
+	},
 	{
 		skipDoc:    true,
 		document:   `[1,2]`,
