@@ -19,7 +19,7 @@ func parseStyle(customStyle string) (Style, error) {
 	} else if customStyle == "flow" {
 		return FlowStyle, nil
 	} else if customStyle != "" {
-		return 0, fmt.Errorf("Unknown style %v", customStyle)
+		return 0, fmt.Errorf("unknown style %v", customStyle)
 	}
 	return 0, nil
 }
@@ -71,7 +71,7 @@ func assignStyleOperator(d *dataTreeNavigator, context Context, expressionNode *
 	return context, nil
 }
 
-func getStyleOperator(d *dataTreeNavigator, context Context, expressionNode *ExpressionNode) (Context, error) {
+func getStyleOperator(_ *dataTreeNavigator, context Context, _ *ExpressionNode) (Context, error) {
 	log.Debugf("GetStyleOperator")
 
 	var results = list.New()
